/*
******************************************************************************
* Date: 24th Apr 2008
* Microchip Graphics Library modified for C18. 
* Only font Flash is supported for now. NO bitmap function has been ported yet.
* The major difference between PIC24 and PIC18 is that, data space for RAM
* and ROM are separate. The keyword rom is required to declare constant
* in flash space, i.e. font table for PIC24 is declared as follow:
* const char L25[] = {....}
* wherease, font table for PIC18 is declared as:
* far const rom char L25[] = {...}
* Use of pointer to flash space in PIC18 is also different. This makes 
* modification to Primitive.c and Primitive.h necessary. 
*
* Summary:
*
* Font25PixelsHeight.c and Font35PixelsHeight.c
* 1. Delcare L25[] as far const rom char L25[] for PIC18
* 2. declare structure member ptr as far const rom char* ptr
* 3. declare L25[] as far const rom char L25[] for PIC18
*
* Primitive.h
* 1. ADD typedef SHORT TYPE_MEMORY to promote the enum data type to SHORT for
* C18 complier
* 2. REMOVE FLASH_BYTE and FLASH_WORD for now
* 3. REMOVE BITMAP_FLASH structure for now
* 4. REMOVE #define BITMAP_EXTERNAL EXTDATA for now
* 5. MODIFY FONT_FLASH structure for C18, const char* address -> far const rom char*
* 6. REMOVE #define FONT_EXTERNAL   EXTDATA
* 7. REMOVE #define EXTERNAL_FONT_BUFFER_SIZE    120
*
* Primitive.c
* 1. MODIFY SetFont(void* font), FONT_HEADER* pHeader pointer declared as 
* rom FONT_HEADER* pHeader because program memory space is separate
* from data memory for PIC18. We need the keyword rom to declare a pointer
* to FONT_HEADER in program memory space, i.e. for font table
* 2. MODIFY OutChar(XCHAR ch) by append rom keyword for two pointers
* GLYPH_ENTRY* pChTable &
* BYTE*        pChImage
* 3. MODIFY SHORT GetTextWidth(XCHAR* textString, void* font) by append
* rom keyword for two pointers GLYPH_ENTRY* pChTable & FONT_HEADER* pHeader
* 4. MODIFY GetTextHeight(void* font) to return _fontHeight instead
* 
* MainDemo.c
* 1. Again, due to the same reason that program memory space is separate from
* data memory space, we cannot use the function OutTextXY() like before
* OutTextXY( (GetMaxX()-width)>>1,(GetMaxY()-height)>>1,"Microchip Inc."), instead
* we need to declare an array for the text in ram like
* char s[] = "Microchip Inc.";
* ....and then use OutTextXY as below
* OutTextXY( (GetMaxX()-width)>>1,(GetMaxY()-height)>>1,&s[0]);
* 2. Use includes.h for SYSCLK definition. This defines the CPU clock speed
* The low level driver ILI9320_8BIT.c uses this definition for delay routine
* calculation.
******************************************************************************
*/

/*
******************************************************************************
* Date: 22th Apr 2008
* Change include file from MainDemo.h to includes.h
* IDE upgraded to MPLAB v8.02
******************************************************************************
*/

/*
******************************************************************************
* Date: 17th April 2008
* This demonstration for QA example for the hardware platform
* PIC18LF4550-Eval-Rev4a + TY240-240320-BO Rev 1B
* Microchip Graphics Library port to PIC18. Only Primitive functions ported
* with Font and Picture Drawn function removed just now.
*
* FileName:        MainDemo.c
* Dependencies:    MainDemo.h
* Processor:       PIC18LF4550
* Compiler:        MPLAB C18 student version
* Programmer : 	   John Leung (www.TechToys.com.hk)
* Note:		       Please refer to the original Software License Agreement
*				   from Microchip for details concerning Copyright
******************************************************************************
*/


/*****************************************************************************
 * Microchip Graphics Library Demo Application
 * This program shows how to use the Graphics Primitives Layer.
 *****************************************************************************
 * FileName:        MainDemo.c
 * Dependencies:    MainDemo.h
 * Processor:       PIC24
 * Compiler:       	MPLAB C30
 * Linker:          MPLAB LINK30
 * Company:         Microchip Technology Incorporated
 *
 * Software License Agreement
 *
 * Copyright ?2007 Microchip Technology Inc.  All rights reserved.
 * Microchip licenses to you the right to use, modify, copy and distribute
 * Software only when embedded on a Microchip microcontroller or digital
 * signal controller, which is integrated into your product or third party
 * product (pursuant to the sublicense terms in the accompanying license
 * agreement).  
 *
 * You should refer to the license agreement accompanying this Software
 * for additional information regarding your rights and obligations.
 *
 * SOFTWARE AND DOCUMENTATION ARE PROVIDED AS IS?WITHOUT WARRANTY OF ANY
 * KIND, EITHER EXPRESS OR IMPLIED, INCLUDING WITHOUT LIMITATION, ANY WARRANTY
 * OF MERCHANTABILITY, TITLE, NON-INFRINGEMENT AND FITNESS FOR A PARTICULAR
 * PURPOSE. IN NO EVENT SHALL MICROCHIP OR ITS LICENSORS BE LIABLE OR
 * OBLIGATED UNDER CONTRACT, NEGLIGENCE, STRICT LIABILITY, CONTRIBUTION,
 * BREACH OF WARRANTY, OR OTHER LEGAL EQUITABLE THEORY ANY DIRECT OR INDIRECT
 * DAMAGES OR EXPENSES INCLUDING BUT NOT LIMITED TO ANY INCIDENTAL, SPECIAL,
 * INDIRECT, PUNITIVE OR CONSEQUENTIAL DAMAGES, LOST PROFITS OR LOST DATA,
 * COST OF PROCUREMENT OF SUBSTITUTE GOODS, TECHNOLOGY, SERVICES, OR ANY
 * CLAIMS BY THIRD PARTIES (INCLUDING BUT NOT LIMITED TO ANY DEFENSE THEREOF),
 * OR OTHER SIMILAR COSTS.
 *
 * Author               Date        Comment
 *~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
 * Anton Alkhimenok		30/05/07	...
 *****************************************************************************/


#include "includes.h"
/*
********************************************************************************************************************
*												Pragma Section
*
* Configuration bits under MPLAB v7.60 subject to changes on every little change on project settings.
* So #pragma config statments used for configuration bits instead of using Configuration bits tab in MPLAB
* Refer to pdf document "mcc18\doc\MPLAB-C18-Addendum.pdf" under mcc18 installation directory for config
* variables available
********************************************************************************************************************
*/
#pragma config PLLDIV = 5			// 20Mhz crystal input, the PLL divider has to be 5 for a fixed 4MHz input to PLL
#pragma config FOSC   = HSPLL_HS	// HS oscillator, PLL sourced
#pragma config CPUDIV = OSC1_PLL2	// Since it is now PLL sourced, the CPU clock = 96MHz PLL/2 => 48MHz
									// From specification the max. clock is around 20MHz for Vdd=3.3V
									// This scenario is like a bit over-clocking the microcontroller!
#pragma config PWRT   = ON			// PowerUp timer ON
#pragma config WDT    = OFF			// watchdog timer off
#pragma config LVP    = OFF			// low level voltage progamming OFF
#pragma config BOR    = OFF			// brown out detect off
#pragma config DEBUG  = ON			// Debug ON
#pragma config PBADEN = OFF 		// PORTB<4:0> as digital IO on reset
#pragma config STVREN = ON  		// Stack overflow reset ON
#pragma config VREGEN = OFF			// Disable internal 3.3V regulator!

///////////////////////////////// FONTS ///////////////////////////////////////
extern FONT_FLASH Font25;

///////////////////////////////// FONTS ///////////////////////////////////////

char s[] = "TECHTOYS CO.";
char c[] = "www.TechToys.com.hk";

void main(void){

SHORT width, height;
SHORT counter;
const SHORT polyPoints[] = {
160,60,
240,120,
160,180,
80,120,
160,60,
};

    InitGraph();

	while(1)
	{	
		SetColor(LIGHTGRAY);

        for(counter=0; counter<GetMaxX(); counter+=20){
            Line(counter,0,GetMaxX()-1-counter,GetMaxY()-1);
        }

        SetFont(&Font25);
        SetColor(BRIGHTGREEN);
        width = GetTextWidth(&c[0],&Font25);
        height = GetTextHeight(&Font25);
        OutTextXY( (GetMaxX()-width)>>1,(GetMaxY()-height)>>1,&c[0]);

        SetFont(&Font25);
        SetColor(BRIGHTRED);
        width = GetTextWidth(&s[0],&Font25);
        height = GetTextHeight(&Font25);
        OutTextXY( (GetMaxX()-width)>>1,100,&s[0]);	

        DelayMs(2000);  

        SetColor(BRIGHTRED);

        for(counter=10; counter<GetMaxY()>>1; counter+=10){
            Circle(GetMaxX()>>1,GetMaxY()>>1,counter);
        }

        DelayMs(2000);  

        SetColor(BRIGHTBLUE);
        FillCircle(GetMaxX()>>1,GetMaxY()>>1,60);
        SetColor(BRIGHTGREEN);
        FillCircle(GetMaxX()>>1,GetMaxY()>>1,40);
        SetColor(BRIGHTRED);
        FillCircle(GetMaxX()>>1,GetMaxY()>>1,20);

        DelayMs(2000);  

        SetColor(BLACK);
        ClearDevice();

        SetColor(BRIGHTBLUE);
        Bevel((GetMaxX()>>1)-60,(GetMaxY()>>1)-60,(GetMaxX()>>1)+60,(GetMaxY()>>1)+60,30);
        SetColor(BRIGHTGREEN);
        Bevel((GetMaxX()>>1)-40,(GetMaxY()>>1)-40,(GetMaxX()>>1)+40,(GetMaxY()>>1)+40,30);
        SetColor(BRIGHTRED);
        Bevel((GetMaxX()>>1)-20,(GetMaxY()>>1)-20,(GetMaxX()>>1)+20,(GetMaxY()>>1)+20,30);

        DelayMs(2000);  

        SetColor(BLACK);
        ClearDevice();

        SetColor(BRIGHTBLUE);
        Arc((GetMaxX()>>1)-60,(GetMaxY()>>1)-60,(GetMaxX()>>1)+60,(GetMaxY()>>1)+60,20,30,0xFF);
        SetColor(BRIGHTGREEN);
        Arc((GetMaxX()>>1)-40,(GetMaxY()>>1)-40,(GetMaxX()>>1)+40,(GetMaxY()>>1)+40,20,30,0xFF);
        SetColor(BRIGHTRED);
        Arc((GetMaxX()>>1)-20,(GetMaxY()>>1)-20,(GetMaxX()>>1)+20,(GetMaxY()>>1)+20,20,30,0xFF);

        DelayMs(2000);  

        SetColor(BRIGHTBLUE);
        FillBevel((GetMaxX()>>1)-60,(GetMaxY()>>1)-60,(GetMaxX()>>1)+60,(GetMaxY()>>1)+60,30);
        SetColor(BRIGHTGREEN);
        FillBevel((GetMaxX()>>1)-40,(GetMaxY()>>1)-40,(GetMaxX()>>1)+40,(GetMaxY()>>1)+40,30);
        SetColor(BRIGHTRED);
        FillBevel((GetMaxX()>>1)-20,(GetMaxY()>>1)-20,(GetMaxX()>>1)+20,(GetMaxY()>>1)+20,30);

        DelayMs(2000);  

        SetColor(BLACK);
        ClearDevice();

        SetColor(BRIGHTBLUE);
        Arc((GetMaxX()>>1),(GetMaxY()>>1)-50,(GetMaxX()>>1),(GetMaxY()>>1)+50,50,60,0x11);
        SetColor(BRIGHTGREEN);
        Arc((GetMaxX()>>1),(GetMaxY()>>1)-50,(GetMaxX()>>1),(GetMaxY()>>1)+50,50,60,0x22);
        SetColor(BRIGHTRED);
        Arc((GetMaxX()>>1),(GetMaxY()>>1)-50,(GetMaxX()>>1),(GetMaxY()>>1)+50,50,60,0x44);
        SetColor(BRIGHTYELLOW);
        Arc((GetMaxX()>>1),(GetMaxY()>>1)-50,(GetMaxX()>>1),(GetMaxY()>>1)+50,50,60,0x88);

        SetColor(BRIGHTBLUE);
        Arc((GetMaxX()>>1),(GetMaxY()>>1)-30,(GetMaxX()>>1),(GetMaxY()>>1)+30,35,45,0x11);
        SetColor(BRIGHTGREEN);
        Arc((GetMaxX()>>1),(GetMaxY()>>1)-30,(GetMaxX()>>1),(GetMaxY()>>1)+30,35,45,0x22);
        SetColor(BRIGHTRED);
        Arc((GetMaxX()>>1),(GetMaxY()>>1)-30,(GetMaxX()>>1),(GetMaxY()>>1)+30,35,45,0x44);
        SetColor(BRIGHTYELLOW);
        Arc((GetMaxX()>>1),(GetMaxY()>>1)-30,(GetMaxX()>>1),(GetMaxY()>>1)+30,35,45,0x88);

        SetColor(BRIGHTBLUE);
        Arc((GetMaxX()>>1),(GetMaxY()>>1),(GetMaxX()>>1),(GetMaxY()>>1),20,30,0x11);
        SetColor(BRIGHTGREEN);
        Arc((GetMaxX()>>1),(GetMaxY()>>1),(GetMaxX()>>1),(GetMaxY()>>1),20,30,0x22);
        SetColor(BRIGHTRED);
        Arc((GetMaxX()>>1),(GetMaxY()>>1),(GetMaxX()>>1),(GetMaxY()>>1),20,30,0x44);
        SetColor(BRIGHTYELLOW);
        Arc((GetMaxX()>>1),(GetMaxY()>>1),(GetMaxX()>>1),(GetMaxY()>>1),20,30,0x88);

        DelayMs(2000);  

        SetColor(BLACK);
        ClearDevice();

        SetColor(BRIGHTBLUE);

        for(counter=0; counter<GetMaxY()>>1; counter+=20){
            Rectangle(GetMaxX()/2-counter,
                      GetMaxY()/2-counter,
                      GetMaxX()/2+counter,
                      GetMaxY()/2+counter);
        }

        DelayMs(2000);  

        SetColor(BRIGHTBLUE);
        Bar(GetMaxX()/2-80,GetMaxY()/2-80,
            GetMaxX()/2+80,GetMaxY()/2+80);
        SetColor(BRIGHTGREEN);
        Bar(GetMaxX()/2-60,GetMaxY()/2-60,
            GetMaxX()/2+60,GetMaxY()/2+60);
        SetColor(BRIGHTRED);
        Bar(GetMaxX()/2-40,GetMaxY()/2-40,
            GetMaxX()/2+40,GetMaxY()/2+40);

        DelayMs(2000);  
        SetColor(BLACK);
        ClearDevice();

        SetColor(WHITE);
        DrawPoly(5,(SHORT*)polyPoints);

        DelayMs(2000);  
        SetColor(BLACK);
        ClearDevice();

        SetFont(&Font25);
        SetColor(BRIGHTGREEN);
        width = GetTextWidth(&c[0],&Font25);
        height = GetTextHeight(&Font25);
        OutTextXY( (GetMaxX()-width)>>1,(GetMaxY()-height)>>1,&c[0]);
		DelayMs(2000);
		
		SetColor(BLACK);
		ClearDevice();	

        SetFont(&Font25);
        SetColor(WHITE);
        width = GetTextWidth(&s[0],&Font25);
        height = GetTextHeight(&Font25);
        OutTextXY( (GetMaxX()-width)>>1,(GetMaxY()-height)>>1,&s[0]);
		DelayMs(2000);	

		SetColor(BLACK);
		ClearDevice();			
		}
}
